@@ -61,7 +61,7 @@ class Pod(BaseResource):
 
     @classmethod
     def k8s_delete_method(cls, broker: Broker, **kwargs: Any) -> models.V1Status:
-        return broker.core_v1_api.delete_namespaces_pod(**kwargs)
+        return broker.core_v1_api.delete_namespaced_pod(**kwargs)
 
     @classproperty
     def kind(self) -> str:
